define(
//begin v1.x content
({
	singleSort: "Jedan sort",
	nestedSort: "Ugniježđeni sort",
	ascending: "Uzlazno",
	descending: "Silazno",
	sortingState: "${0} - ${1}",
	unsorted: "Ne sortiraj ovaj stupac",
	indirectSelectionRadio: "Red ${0}, jedan izbor, radio kućica",
	indirectSelectionCheckBox: "Red ${0}, više izbora, kontrolna kućica",
	selectAll: "Izaberi sve"
})
//end v1.x content
);

